# ArviZ `InferenceData` examples

This repository contains metadata of ArviZ InferenceData examples and the code used to generate some of the examples.
Example models stored remotely are listed in `data_remote.json`.
Example models stored locally are listed in `data_local.json`, and the data themselves are stored in `data/`.
Inclusion of the code serves both as extra information on the models in the JSON files and to ease updating these examples whenever necessary.

When applicable, code for a model should be added as an executable file (e.g. `.py` or `.ipynb`) to a directory in `code/` of the same name as the model.
